@@ -10,9 +10,10 @@ class PluginApp(AppConfig):
         name = gettext_lazy('Saferpay (SIX)')
         author = 'Raphael Michel'
         category = 'PAYMENT'
-        description = gettext_lazy('This allows to accept payments through saferpay.')
+        description = gettext_lazy('Accept payments through Saferpay, a payment method offered by Worldline (formerly SIX Payment Services).')
         visible = True
-        version = '1.3.0'
+        picture = "pretix_saferpay/logo.svg"
+        version = '1.3.1'
 
     def ready(self):
         from . import signals, tasks  # NOQA
